IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'CALCULA_SALDO_ANTERIOR'  AND
	        TYPE = 'P' 			        AND
	        U.UID = O.UID             		        AND
	        U.NAME = USER)

DROP PROCEDURE CALCULA_SALDO_ANTERIOR
GO

CREATE PROCEDURE CALCULA_SALDO_ANTERIOR  @P_CDFILIAL       VARCHAR(04),
                                         @P_NRLANCESTQ     VARCHAR(10),
                                         @P_CDFILIMOVI     VARCHAR(04),
                                         @P_CDPRODUTO      VARCHAR(10),
                                         @P_CDALMOXARIFE   VARCHAR(06),
                                         @P_CDLOCALESTOQ   VARCHAR(06),
                                         @P_NRLOTEESTQ     VARCHAR(04),
                                         @P_NRSUBLOTE      VARCHAR(04),
                                         @P_DTPOSIESTQ     DATETIME,
                                         @P_MOVI           VARCHAR(02) = 'S',
                                         @P_QTESTOQDIA     DOUBLE PRECISION OUTPUT,
                                         @P_VRESTOQDIA     DOUBLE PRECISION OUTPUT,
                                         @P_VRESTOQBRUT    DOUBLE PRECISION OUTPUT,
                                         @P_QTESTOQANT     DOUBLE PRECISION OUTPUT,
                                         @P_VRESTANT       DOUBLE PRECISION OUTPUT


AS
   DECLARE   @V_QTDEESTO      DOUBLE PRECISION;
   DECLARE   @V_VALRESTO      DOUBLE PRECISION;
   DECLARE   @V_VALRBRUT      DOUBLE PRECISION;
   DECLARE   @V_QTDEANTE      DOUBLE PRECISION;
   DECLARE   @V_VRESTANT      DOUBLE PRECISION;
   DECLARE   @V_VRBRUANT      DOUBLE PRECISION;
   DECLARE   @V_QTDEESTOPOS   DOUBLE PRECISION;
   DECLARE   @V_VALRESTOPOS   DOUBLE PRECISION;
   DECLARE   @V_VALRBRUTPOS   DOUBLE PRECISION;
   DECLARE   @V_QTDEANTEPOS   DOUBLE PRECISION;
   DECLARE   @V_VRESTANTPOS   DOUBLE PRECISION;
   DECLARE   @V_VRBRUANTPOS   DOUBLE PRECISION;
   DECLARE   @V_COUNTPOS      DOUBLE PRECISION;

   DECLARE   @V_QTESTOQDIA    DOUBLE PRECISION;
   DECLARE   @V_VRESTOQDIA    DOUBLE PRECISION;
   DECLARE   @V_VRESTOQBRUT   DOUBLE PRECISION;
   DECLARE   @V_IDRETORNO     VARCHAR(01);

   DECLARE   @V_NRLANCESTQ    VARCHAR(14);
   DECLARE   @V_DTAUXILIAR    DATETIME;
   DECLARE   @V_IDTIPOMOVI    VARCHAR(1);
   DECLARE   @V_DTLANCMOVI    DATETIME;
   DECLARE   @V_VRLANCTOEST   DOUBLE PRECISION;
   DECLARE   @V_VRLANCTOBRUT  DOUBLE PRECISION;
   DECLARE   @V_QTLANCTOEST   DOUBLE PRECISION;
   DECLARE   @V_IDALTCMEDMV   VARCHAR(1);
   DECLARE   @V_CDFILIAL      VARCHAR(04);
   DECLARE   @V_LANCESTOQ     VARCHAR(14);

   DECLARE   @V_TIPCUSTEST   DOUBLE PRECISION;
   DECLARE   @V_CUSTESTOQ    DOUBLE PRECISION;
   DECLARE   @V_DATAPROC     DATETIME;
   DECLARE   @V_COUNT        DOUBLE PRECISION;
   DECLARE   @V_CDTIPOOPER   VARCHAR(2);

BEGIN
   SET @V_QTDEESTOPOS  = 0;
   SET @V_VALRESTOPOS  = 0;
   SET @V_VALRBRUTPOS  = 0;
   SET @V_QTDEANTEPOS  = 0;
   SET @V_VRESTANTPOS  = 0;
   SET @V_VRBRUANTPOS  = 0;
   SET @V_DTAUXILIAR   = NULL;
   SET @V_TIPCUSTEST   = 0;
   SET @V_DATAPROC     = NULL;
   SET @V_COUNT        = 0;

    
   SELECT @V_QTDEESTOPOS = ISNULL(MAX(QTESTOQDIA),0),
          @V_VALRESTOPOS = ISNULL(MAX(VRESTOQDIA),0),
          @V_VALRBRUTPOS = ISNULL(MAX(VRESTOQBRUT),0),
          @V_QTDEANTEPOS = ISNULL(MAX(QTESTOQANT),0),
          @V_VRESTANTPOS = ISNULL(MAX(VRESTOQANT),0),
          @V_VRBRUANTPOS = ISNULL(MAX(VRBRUTOANT),0),
          @V_DTAUXILIAR  = MAX(DTPOSIESTQ),
          @V_COUNT       = COUNT(*) 
   FROM POSESTDIA
   WHERE (CDFILIAL     = @P_CDFILIMOVI)   AND
         (CDALMOXARIFE = @P_CDALMOXARIFE) AND
         (CDLOCALESTOQ = @P_CDLOCALESTOQ) AND
         (NRLOTEESTQ   = @P_NRLOTEESTQ)   AND
         (NRSUBLOTE    = @P_NRSUBLOTE)    AND
         (CDPRODUTO    = @P_CDPRODUTO)    AND
         (DTPOSIESTQ   = @P_DTPOSIESTQ);

   IF @V_COUNT = 0 BEGIN
      SELECT @V_QTDEESTOPOS = ISNULL(MAX(QTESTOQDIA),0),
             @V_VALRESTOPOS = ISNULL(MAX(VRESTOQDIA),0),
             @V_VALRBRUTPOS = ISNULL(MAX(VRESTOQBRUT),0),
             @V_QTDEANTEPOS = ISNULL(MAX(QTESTOQANT),0),
             @V_VRESTANTPOS = ISNULL(MAX(VRESTOQANT),0),
             @V_VRBRUANTPOS = ISNULL(MAX(VRBRUTOANT),0),
             @V_DTAUXILIAR  =  MAX(DTPOSIESTQ)
      FROM POSESTDIA
      WHERE (CDFILIAL     = @P_CDFILIMOVI)   AND
            (CDALMOXARIFE = @P_CDALMOXARIFE) AND
            (CDLOCALESTOQ = @P_CDLOCALESTOQ) AND
            (NRLOTEESTQ   = @P_NRLOTEESTQ)   AND
            (NRSUBLOTE    = @P_NRSUBLOTE)    AND
            (CDPRODUTO    = @P_CDPRODUTO)    AND
            (DTPOSIESTQ   = (SELECT MAX(DTPOSIESTQ)
                             FROM POSESTDIA
                             WHERE (CDFILIAL     = @P_CDFILIMOVI)   AND
                                   (CDALMOXARIFE = @P_CDALMOXARIFE) AND
                                   (CDLOCALESTOQ = @P_CDLOCALESTOQ) AND
                                   (NRLOTEESTQ   = @P_NRLOTEESTQ)   AND
                                   (NRSUBLOTE    = @P_NRSUBLOTE)    AND
                                   (CDPRODUTO    = @P_CDPRODUTO)    AND
                                   (DTPOSIESTQ   <= @P_DTPOSIESTQ)));
   END;

   SET @V_QTDEESTO   = @V_QTDEESTOPOS;
   SET @V_VALRESTO   = @V_VALRESTOPOS;
   SET @V_VALRBRUT   = @V_VALRBRUTPOS;
   SET @V_QTDEANTE   = @V_QTDEANTEPOS;
   SET @V_VRESTANT   = @V_VRESTANTPOS;
   SET @V_VRBRUANT   = @V_VRBRUANTPOS;

   SET @P_VRESTANT   = @V_VALRESTOPOS;
   SET @P_QTESTOQANT = @V_QTDEESTOPOS;

   IF (@V_QTDEESTO <> 0) BEGIN
      SET @V_QTDEANTE = @V_QTDEANTEPOS;
      SET @V_VRESTANT = @V_VRESTANTPOS;
      SET @V_VRBRUANT = @V_VRBRUANTPOS;
   END;

   SET @V_QTESTOQDIA  = 0;
   SET @V_VRESTOQDIA  = 0;
   SET @V_VRESTOQBRUT = 0;
   SET @V_IDRETORNO   = 'N';
   SET @V_NRLANCESTQ  = 'X';

   DECLARE C_MOVIESTQ CURSOR FOR
      SELECT I.IDTIPOMOVI, I.DTLANCMOVI, ISNULL(I.VRLANCTOEST,0) VRLANCTOEST,
             ISNULL(I.VRLANCTOBRUT, 0) VRLANCTOBRUT, I.QTLANCTOEST, I.IDALTCMEDMV,
             I.CDFILIAL, I.NRLANCESTQ, L.CDTIPOOPER
      FROM ITLANCTOEST I, LANCTOESTOQ L
      WHERE (I.CDFILIMOVI   = @P_CDFILIMOVI)   AND
            (I.CDALMOXARIFE = @P_CDALMOXARIFE) AND
            (I.CDLOCALESTOQ = @P_CDLOCALESTOQ) AND
            (I.NRLOTEESTQ   = @P_NRLOTEESTQ)   AND
            (I.NRSUBLOTE    = @P_NRSUBLOTE)    AND
            (I.CDPRODMOVI   = @P_CDPRODUTO)    AND
            (I.DTLANCMOVI   = @P_DTPOSIESTQ)   AND
            ((I.IDEVOLESTOQ  = 'S')OR (I.IDEVOLESTOQ IS NULL)) AND
            (I.CDFILIAL     = L.CDFILIAL)      AND
            (I.NRLANCESTQ   = L.NRLANCESTQ)

      ORDER BY ISNULL(I.IDORDEMCLC, I.IDTIPOMOVI), I.NRLANCESTQ, I.NRSEQUITEM;

   OPEN C_MOVIESTQ;

   FETCH NEXT FROM C_MOVIESTQ INTO @V_IDTIPOMOVI,    @V_DTLANCMOVI,  @V_VRLANCTOEST,
                                    @V_VRLANCTOBRUT, @V_QTLANCTOEST, @V_IDALTCMEDMV,
                                    @V_CDFILIAL,     @V_LANCESTOQ, @V_CDTIPOOPER;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      SELECT @V_TIPCUSTEST = ISNULL(MAX(CONVERT(NUMERIC,CDTIPCUSTEST)),3),
             @V_DATAPROC   = MAX(ISNULL(DTPROCESSA, GETDATE()))
      FROM PARAMFILIAL
      WHERE CDFILIAL = @P_CDFILIMOVI;

      IF @P_MOVI <> 'S' BEGIN
         SET @V_TIPCUSTEST = 3;
      END;

      IF (@V_TIPCUSTEST <> 3) BEGIN
         SELECT @V_CUSTESTOQ = TEKNISA.CUSTO_PRODUTO(@P_CDFILIAL, @P_CDPRODUTO, @V_TIPCUSTEST, @P_DTPOSIESTQ, @V_DATAPROC)
         FROM PARAMGERAL;
      END;

      IF (@V_CUSTESTOQ IS NULL) BEGIN
         SET @V_CUSTESTOQ = 0;
      END;

      IF ((@P_CDFILIAL+@P_NRLANCESTQ) = (@V_CDFILIAL+ @V_LANCESTOQ)) AND (@V_IDRETORNO = 'N') BEGIN

         IF (@V_TIPCUSTEST <> 3) BEGIN
            IF (@V_QTDEESTO <> 0) BEGIN
               SET @V_QTESTOQDIA  = @V_QTDEESTO;
            END
            ELSE BEGIN
               SET @V_QTESTOQDIA  = 0;
                IF ROUND(ABS(@V_QTDEANTE),8) <> 0 BEGIN
                  SET @V_VRESTOQDIA  = @V_VRESTANT;
                  SET @V_VRESTOQBRUT = @V_VRBRUANT;
                  SET @P_QTESTOQANT  = @V_QTDEANTE;
                  SET @P_VRESTANT    = @V_VRESTANT;
               END;
            END;
            SET @V_VRESTOQDIA  =  @V_CUSTESTOQ;
            SET @V_VRESTOQBRUT =  @V_CUSTESTOQ;
         END
         ELSE BEGIN
            IF @V_QTDEESTO <> 0 BEGIN
               SET @V_QTESTOQDIA  = @V_QTDEESTO;
               SET @V_VRESTOQDIA  = @V_VALRESTO;
               SET @V_VRESTOQBRUT = @V_VALRBRUT;
            END
            ELSE BEGIN
               SET @V_QTESTOQDIA  = 0;
               IF ROUND(ABS(@V_QTDEANTE),8) <> 0 BEGIN
                  SET @V_VRESTOQDIA  = @V_VRESTANT;
                  SET @V_VRESTOQBRUT = @V_VRBRUANT;
                  SET @P_QTESTOQANT  = @V_QTDEANTE;
                  SET @P_VRESTANT    = @V_VRESTANT;
               END;
            END;
         END;
         SET @V_IDRETORNO = 'S';
      END;

      IF (@V_QTDEESTO <> 0) BEGIN
         SET @V_QTDEANTE = @V_QTDEESTO;
         SET @V_VRESTANT = @V_VALRESTO;
         SET @V_VRBRUANT = @V_VALRBRUT;
      END;

      /* TRATAMENTO PARA CADA REGISTRO DE LANAMENTO DE ESTOQUE */
      IF (@V_IDTIPOMOVI = '0') BEGIN    /* IMPLANTAO */

         IF (@V_NRLANCESTQ <> @V_CDFILIAL+@V_LANCESTOQ) BEGIN
            SET @V_VALRBRUT    = @V_VRLANCTOBRUT;
            SET @V_VALRESTO    = @V_VRLANCTOEST;
            SET @V_QTDEESTO    = @V_QTLANCTOEST;
         END
         ELSE BEGIN
            SET @V_VALRBRUT    = @V_VALRBRUT   + @V_VRLANCTOBRUT;
            SET @V_VALRESTO    = @V_VALRESTO   + @V_VRLANCTOEST;
            SET @V_QTDEESTO    = @V_QTDEESTO   + @V_QTLANCTOEST;
         END;
      END
      ELSE IF (@V_IDTIPOMOVI = '1') BEGIN    /* AJUSTES     */
         IF (ISNULL(@V_IDALTCMEDMV,'N') <> 'S') BEGIN
            IF (@V_TIPCUSTEST <> 3) BEGIN
               SET @V_VALRBRUT = (@V_VALRBRUT * @V_QTLANCTOEST);
               SET @V_VALRESTO = (@V_VALRESTO * @V_QTLANCTOEST);
            END
            ELSE BEGIN
               IF (@V_QTDEESTO = 0) BEGIN
                  IF (@V_QTDEANTE <> 0) BEGIN
                     SET @V_VALRBRUT = (@V_VRBRUANT/@V_QTDEANTE)* @V_QTLANCTOEST;
                     SET @V_VALRESTO = (@V_VRESTANT/@V_QTDEANTE)* @V_QTLANCTOEST;

                     SET @V_VRBRUANT = 0;
                     SET @V_VRESTANT = 0;
                     SET @V_QTDEANTE = 0;
                  END
                  ELSE BEGIN
                     SET @V_VALRBRUT   = 0;
                     SET @V_VALRESTO   = 0;
                     SET @V_VRBRUANT   = 0;
                     SET @V_VRESTANT   = 0;
                     SET @V_QTDEANTE   = 0;
                  END;
               END
               ELSE BEGIN
                  SET @V_VALRBRUT = (@V_VALRBRUT/@V_QTDEESTO)* @V_QTLANCTOEST;
                  SET @V_VALRESTO = (@V_VALRESTO/@V_QTDEESTO)* @V_QTLANCTOEST;
               END;
            END;
         END;

         SET @V_QTDEESTO = @V_QTLANCTOEST;

      END
      ELSE IF (@V_IDTIPOMOVI = '2') BEGIN    /* ENTRADA */
         SET @V_QTDEESTO = @V_QTDEESTO + @V_QTLANCTOEST;

         IF (@V_QTLANCTOEST = 0) BEGIN
            IF @V_CDTIPOOPER = '03' BEGIN
               SET @V_VALRBRUT = @V_VALRBRUT + @V_VRLANCTOBRUT;
               SET @V_VALRESTO = @V_VALRESTO + @V_VRLANCTOEST;
            END;
         END
         ELSE BEGIN
            SET @V_VALRBRUT = @V_VALRBRUT + (@V_QTLANCTOEST * @V_VRLANCTOBRUT);
            SET @V_VALRESTO = @V_VALRESTO + (@V_QTLANCTOEST * @V_VRLANCTOEST);
         END;
      END
      ELSE IF (@V_IDTIPOMOVI = '3') BEGIN    /* RETIRADA    */
         IF (@V_QTDEESTO > 0) BEGIN
            IF (@V_TIPCUSTEST <> 3) BEGIN
               SET @V_VALRESTO = @V_VALRBRUT - ((@V_VRESTOQDIA/@V_QTDEESTO) * @V_QTLANCTOEST);
               SET @V_VALRBRUT = @V_VALRESTO - ((@V_VRESTOQDIA/@V_QTDEESTO) * @V_QTLANCTOEST);
            END
            ELSE BEGIN
               SET @V_VALRBRUT = @V_VALRBRUT - ((@V_VALRBRUT/@V_QTDEESTO)*@V_QTLANCTOEST);
               SET @V_VALRESTO = @V_VALRESTO - ((@V_VALRESTO/@V_QTDEESTO)*@V_QTLANCTOEST);
            END;
         END;

         SET @V_QTDEESTO = @V_QTDEESTO - @V_QTLANCTOEST;

         IF (@V_QTDEESTO < 0) BEGIN
            IF (@V_QTDEANTE <> 0) BEGIN
               IF (@V_TIPCUSTEST <> 3) BEGIN
                  SET @V_VALRESTO = @V_VRESTOQDIA * @V_QTDEESTO;
                  SET @V_VALRBRUT = @V_VRESTOQDIA * @V_QTDEESTO;
               END
               ELSE BEGIN
                  SET @V_VALRESTO = ((@V_VRESTANT/@V_QTDEANTE)*@V_QTDEESTO);
                  SET @V_VALRBRUT = ((@V_VRBRUANT/@V_QTDEANTE)*@V_QTDEESTO);
               END;
            END
            ELSE BEGIN
               SET @V_VALRESTO = 0;
               SET @V_VALRBRUT = 0;
            END;
         END;

         IF (ROUND(@V_QTDEESTO,8) = 0) BEGIN
            SET @V_QTDEESTO = 0;
         END;

         IF (@V_QTDEESTO  = 0) BEGIN
            SET @V_VALRBRUT   = 0;
            SET @V_VALRESTO   = 0;
         END;
      END
      ELSE IF (@V_IDTIPOMOVI = '4') BEGIN    /* SADA       */
         IF (ABS(@V_QTDEESTO) > 0) BEGIN
            IF (@V_QTLANCTOEST <> 0 OR @V_CDTIPOOPER = '03') BEGIN
               SET @V_VALRBRUT = @V_VALRBRUT - ((@V_VALRBRUT/@V_QTDEESTO)*@V_QTLANCTOEST);
               SET @V_VALRESTO = @V_VALRESTO - ((@V_VALRESTO/@V_QTDEESTO)*@V_QTLANCTOEST);
            END;
         END;

         SET @V_QTDEESTO = @V_QTDEESTO - @V_QTLANCTOEST;

         IF (@V_QTDEESTO < 0) BEGIN
            IF (@V_QTDEANTE <> 0) BEGIN
               IF @V_TIPCUSTEST <> 3 BEGIN
                  SET @V_VALRESTO = @V_VRESTOQDIA * @V_QTDEESTO;
                  SET @V_VALRBRUT = @V_VRESTOQDIA * @V_QTDEESTO;
	       END  	
               ELSE BEGIN
                  SET @V_VALRESTO = ((@V_VRESTANT/@V_QTDEANTE)*@V_QTDEESTO);
                  SET @V_VALRBRUT = ((@V_VRBRUANT/@V_QTDEANTE)*@V_QTDEESTO);
               END;
            END
            ELSE BEGIN
               SET @V_VALRESTO = 0;
               SET @V_VALRBRUT = 0;
            END;
         END;

         IF (ROUND(@V_QTDEESTO,8) = 0) BEGIN
            SET @V_QTDEESTO = 0;
         END;

         IF (@V_QTDEESTO = 0) BEGIN
            SET @V_VALRBRUT = 0;
            SET @V_VALRESTO = 0;
         END;
      END
      ELSE IF (@V_IDTIPOMOVI = '5') BEGIN    /* DEV. FORN.  */
         IF NOT (@V_LANCESTOQ = @P_NRLANCESTQ) BEGIN  /* Incluido em virtude das sol. 87061 e 87042*/

            IF (@V_QTLANCTOEST = 0) BEGIN
               SET @V_VALRBRUT = @V_VALRBRUT - @V_VRLANCTOBRUT;
               SET @V_VALRESTO = @V_VALRESTO - @V_VRLANCTOEST;
            END
            ELSE BEGIN
               SET @V_VALRBRUT = @V_VALRBRUT - (@V_QTLANCTOEST*@V_VRLANCTOBRUT);
               SET @V_VALRESTO = @V_VALRESTO - (@V_QTLANCTOEST*@V_VRLANCTOEST);
            END;


            SET @V_QTDEESTO = @V_QTDEESTO - @V_QTLANCTOEST;

            IF (ROUND(@V_QTDEESTO,3) = 0) BEGIN
               SET @V_QTDEESTO = 0;
            END;

            IF (@V_QTDEESTO  = 0) BEGIN
               SET @V_VALRBRUT   = 0;
               SET @V_VALRESTO   = 0;
            END;
         END
         ELSE BEGIN/* Incluido em virtude das sol. 87061 e 87042*/

            IF @V_VALRESTO - (@V_QTLANCTOEST * @V_VRLANCTOEST) >= 0 BEGIN
               SET @V_VALRESTO = @V_VRLANCTOEST/@V_QTLANCTOEST;
               SET @V_VALRBRUT = @V_VRLANCTOBRUT/@V_QTLANCTOEST;
            END
            ELSE BEGIN
               IF @V_QTDEESTO <> 0 BEGIN
                  SET @V_VALRESTO = @V_VALRESTO/@V_QTDEESTO;
                  SET @V_VALRBRUT = @V_VALRBRUT/@V_QTDEESTO;
               END
               ELSE BEGIN
                  SET @V_VALRESTO = TEKNISA.CUSTO_PRODUTO(@P_CDFILIAL, @P_CDPRODUTO, @V_TIPCUSTEST, @P_DTPOSIESTQ, @V_DATAPROC);
                  SET @V_VALRBRUT = TEKNISA.CUSTO_PRODUTO(@P_CDFILIAL, @P_CDPRODUTO, @V_TIPCUSTEST, @P_DTPOSIESTQ, @V_DATAPROC);
               END
            END;

            SET @V_VRESTOQDIA  = @V_VALRESTO;
            SET @V_VRESTOQBRUT = @V_VALRBRUT;
            BREAK;
         END;
      END;

      /* GUARDA OS VALORES DE ESTOQUE ANTERIORES  PRXIMA MOVIMENTAO */
      SET @V_QTDEESTOPOS   = @V_QTDEESTO;
      SET @V_VALRESTOPOS   = @V_VALRESTO;
      SET @V_VALRBRUTPOS   = @V_VALRBRUT;
      SET @V_QTDEANTEPOS   = @V_QTDEANTE;
      SET @V_VRESTANTPOS   = @V_VRESTANT;
      SET @V_VRBRUANTPOS   = @V_VRBRUANT;

      SET @V_NRLANCESTQ = @V_CDFILIAL+@V_LANCESTOQ;

      FETCH NEXT FROM C_MOVIESTQ INTO  @V_IDTIPOMOVI,   @V_DTLANCMOVI,  @V_VRLANCTOEST,
                                       @V_VRLANCTOBRUT, @V_QTLANCTOEST, @V_IDALTCMEDMV,
                                       @V_CDFILIAL,     @V_LANCESTOQ,   @V_CDTIPOOPER;
   END;

   CLOSE C_MOVIESTQ;
   DEALLOCATE C_MOVIESTQ;




   SET @P_QTESTOQDIA  = @V_QTESTOQDIA;
   SET @P_VRESTOQDIA  = @V_VRESTOQDIA;
   SET @P_VRESTOQBRUT = @V_VRESTOQBRUT;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CALCULA_SALDO_ANTERIOR','6.05.XXX';
GO

