const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const protractorHelper = require('protractor-helper');
const j = require('../../../json/leitorJson.po.js');
const apuracaoContribuicaoPage = require('../../../page-objects/fiscal/imposto/apuracaoContribuicao.po.js');

const gridApuraContrib = '632245607852701542806';
const gridAjusteCredito = '63224560721945302391130';
const gridAjusteDebito = '63224560721945302391130';

describe('Tela Apuração de Imposto', () => {
    beforeAll(() => {
        loginPage.login(j.getValor('login'), j.getValor('senha'));
        apuracaoContribuicaoPage.abrir();
        geral.selectNative('IDTIPOAPURA', 'Federal');
        geral.searchAndClickGridField('NMEMPRESA', j.getValor('empresa'), 'NMRAZSOCEMPR');
        geral.searchAndClickGridField('DSIMPOSTONFE', j.getValor('imposto'), 'CDIMPOSTONFE');
        apuracaoContribuicaoPage.clickFiltrar();
    });

    afterAll(() => {
        geral.sair();
    });

    it('Acessar tela Apuração de Imposto', () => {
        geral.esperarLoading();

        expect(z.component.header.getTitle())
            .toBe('Apuração de Imposto');
    });

    it('Adicionar mapa contribuições', () => {
        geral.clickAdicionar();
        geral.clickAndFillField('NMMAPAAPUR', j.getValor('nomeMapaContrib'));
        apuracaoContribuicaoPage.inserirDataInicial(j.getValor('dataInicial'));
        apuracaoContribuicaoPage.inserirDataFinal(j.getValor('dataFinal'));
        geral.clickSalvar();
        geral.clickVoltar();

        expect(geral.gridHasText(gridApuraContrib, j.getValor('nomeMapaContrib'), 1))
            .toEqual('Apuração Contribuição');
    });

    it('Apurar mapa contribuições', () => {
        geral.clickGrid('NMMAPAAPUR', j.getValor('nomeMapaContrib'), gridApuraContrib);
        geral.clickAcoes();
        geral.clickActionPorIndice(1);
        geral.clickNão();
        geral.clickOk();
        geral.clickVoltar();

        expect(geral.gridHasText(gridApuraContrib, j.getValor('dataInicial'), 2))
            .toEqual('01/01/2020');
        expect(geral.gridHasText(gridApuraContrib, j.getValor('dataFinal'), 3))
            .toEqual('31/01/2020');
        var status = z.widget.grid.getText(gridApuraContrib, 0, 6, false);
        status.getText().then(function (resultado) {
            expect(resultado).toEqual('Apurado');
        });
    });

    it('Editar Ajuste Acréscimo Crédito/Entrada', () => {
        geral.clickGrid('NMMAPAAPUR', j.getValor('nomeMapaContrib'), gridApuraContrib);
        geral.trocarAba('Detalhamento');
        geral.clickField('CONTABAJUSTCREDACRES');
        geral.clickAdicionar();
        apuracaoContribuicaoPage.ajusteCredito(j.getValor('ajusteCredito'), j.getValor('tipoCredito'),
            j.getValor('regimeApuracao'), j.getValor('valorCredito'),
            j.getValor('processoCredito'), j.getValor('descricaoAjuste'),
            j.getValor('dataAcrescimo'));
        geral.clickSalvar();

        expect(geral.gridHasText(gridAjusteCredito, j.getValor('valorCredito'), 1))
            .toEqual('1.000,00');
        expect(geral.gridHasText(gridAjusteCredito, j.getValor('ajusteCredito'), 0))
            .toEqual('02 - Ajuste Oriundo de Processo Administrativo');
    });

    it('Excluir Ajuste Acréscimo Crédito/Entrada', () => {
        geral.clickGrid('CDAJUSTE', j.getValor('ajusteCredito'), gridAjusteCredito);
        geral.clickExcluir();
        geral.clickSim();
        geral.clickVoltar();

        var acresCredito = element.all(by.css('#span-field-VRAJUSTECREDENTR > p'));
        acresCredito.getText().then(function (credito) {
            expect(credito).toEqual(['0,00']);
        });
    });

///////////////  Nota de esclarecimento  //////////////////
               /*
               Esta situação não pode ser exetuda, pois está com erro de restrição violada.
               O erro será tratado com base na issue 250781.
               */

    // it('Editar Ajuste Acréscimo Débito/Saída', () => {
    //     geral.clickField('CONTABAJUSTDEBACRES');
    //     geral.clickAdicionar();
    //     apuracaoContribuicaoPage.ajusteDebito(j.getValor('ajusteDebito'), j.getValor('regimeApuracao'),
    //         j.getValor('cst'), j.getValor('valorDebito'),
    //         j.getValor('processoDebito'), j.getValor('descricaoAjuste'),
    //         j.getValor('dataAcrescimo'));
    //     geral.clickSalvar();

    //     expect(geral.gridHasText(gridAjusteDebito, j.getValor('valorCredito'), 1))
    //         .toEqual('1.000,00');
    //     expect(geral.gridHasText(gridAjusteDebito, j.getValor('ajusteCredito'), 0))
    //         .toEqual('03 - Ajuste Oriundo da Legislação Tributária');
    // });

    // it('Excluir Ajuste Acréscimo Débito/Saída', () => {
    //     geral.clickGrid('CDAJUSTE', j.getValor('ajusteDebito'), gridAjusteDebito);
    //     geral.clickExcluir();
    //     geral.clickSim();
    //     geral.clickVoltar();

    //     var acresDebito = element.all(by.css('#span-field-VRAJUSTECREDSAID > p'));
    //     acresDebito.getText().then(function (debito) {
    //         expect(debito).toEqual(['0,00']);
    //     });
    // });

    it('Editar nome do mapa', () => {
        geral.trocarAba('Apuração de Imposto');
        geral.clickEditar();
        geral.fillField('NMMAPAAPUR', j.getValor('editMapaContrib'));
        geral.clickSalvar();

        var name = element.all(by.css('#span-field-NMMAPAAPUR > p'));
        name.getText().then(function (nome) {
            expect(nome).toEqual(['Janeiro/2020']);
        });
    });

    it('Editar status do mapa', () => {
        geral.clickAcoes();
        geral.clickActionPorIndice(2);
        geral.clickOk();

        var situacao = element.all(by.css('#span-field-IDBLOQMAPAPU > p'));
        situacao.getText().then(function (status) {
            expect(status).toEqual(['Bloqueado']);
        });

        geral.clickAcoes();
        geral.clickActionPorIndice(3);
        geral.clickOk();

        var locked = element.all(by.css('#span-field-IDBLOQMAPAPU > p'));
        locked.getText().then(function (unlocked) {
            expect(unlocked).toEqual(['Apurado'])
        });
    });

    it('Excluir Mapa Contribuições', () => {
        geral.clickExcluir();
        geral.clickSim();
        geral.clickOk();

        z.widget.grid.getNrRowsFromGroupedGrid(gridApuraContrib)
            .then(function (excluir) {
                expect(excluir).toEqual(0);
            });
    });
});